@@ -21,12 +21,12 @@ apt-get install build-essential kernel-package || die "Can't install packages."
 sed -i -e 's/maintainer := .*/maintainer := Tetsuo Handa/' -e 's/email := .*/email := penguin-kernel@I-love.SAKURA.ne.jp/' -- /etc/kernel-pkg.conf || die "Can't edit /etc/kernel-pkg.conf ."
 
 # Download CaitSith patches.
-mkdir -p /root/rpmbuild/SOURCES/
-cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r caitsith-patch-0.1-20160808.tar.gz ]
+mkdir -p ~/rpmbuild/SOURCES/
+cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
+if [ ! -r caitsith-patch-0.1-20160928.tar.gz ]
 then
     apt-get -y install wget
-    wget -O caitsith-patch-0.1-20160808.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20160808.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.1-20160928.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20160928.tar.gz' || die "Can't download patch."
 fi
 
 # Install kernel source packages.
@@ -38,7 +38,7 @@ tar -jxf linux-source-3.2.tar.bz2
 
 # Apply patches and create kernel config.
 cd linux-source-3.2 || die "Can't chdir to linux-source-3.2/ ."
-tar -zxf /root/rpmbuild/SOURCES/caitsith-patch-0.1-20160808.tar.gz || die "Can't extract patch."
+tar -zxf ~/rpmbuild/SOURCES/caitsith-patch-0.1-20160928.tar.gz || die "Can't extract patch."
 sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 patch -p1 < patches/ccs-patch-3.2-debian-wheezy.diff || die "Can't apply patch."
 cat /boot/config-3.2.0-$ABI_VERSION-$ORIGINAL_FLAVOUR config.caitsith > .config || die "Can't create config."
