@@ -17,14 +17,14 @@ fi
 LANG=C rpm --checksig kernel-3.4.110-4vl6.src.rpm | grep -F ': (sha1) dsa sha1 md5 gpg OK' || die "Can't verify signature."
 rpm -ivh kernel-3.4.110-4vl6.src.rpm || die "Can't install source package."
 
-cd /root/rpm/SOURCES/ || die "Can't chdir to /root/rpm/SOURCES/ ."
-if [ ! -r caitsith-patch-0.1-20160808.tar.gz ]
+cd ~/rpm/SOURCES/ || die "Can't chdir to ~/rpm/SOURCES/ ."
+if [ ! -r caitsith-patch-0.1-20160928.tar.gz ]
 then
-    wget -O caitsith-patch-0.1-20160808.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20160808.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.1-20160928.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/55464/caitsith-patch-0.1-20160928.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /root/rpm/SPECS/kernel34-vl.spec . || die "Can't copy spec file."
+cp -p ~/rpm/SPECS/kernel34-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- kernel34-vl.spec
 +++ kernel34-vl.spec
@@ -61,7 +61,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# CaitSith
-+tar -zxf %_sourcedir/caitsith-patch-0.1-20160808.tar.gz
++tar -zxf %_sourcedir/caitsith-patch-0.1-20160928.tar.gz
 +sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 +patch -sp1 < patches/ccs-patch-3.4-vine-linux-6.diff
  cp %{SOURCE10} Documentation/
