@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.16   2016/06/07
+ * Version: 0.1.17   2016/09/28
  */
 
 #ifndef _SECURITY_CAITSITH_INTERNAL_H
@@ -57,6 +57,7 @@
 #include <net/ip.h>
 #include <net/ipv6.h>
 #include <net/udp.h>
+#include <linux/ctype.h>
 
 #ifndef __printf
 #define __printf(a,b) __attribute__((format(printf,a,b)))
@@ -262,6 +263,9 @@ struct caitsith_exports {
 	struct task_struct * (*find_task_by_vpid) (pid_t nr);
 	struct task_struct * (*find_task_by_pid_ns) (pid_t nr,
 						     struct pid_namespace *ns);
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+	size_t (*ksize) (const void *objp);
+#endif
 };
 
 /* Index numbers for Capability Controls. */
@@ -1032,50 +1036,6 @@ static inline pid_t cs_sys_getpid(void)
 	return task_tgid_vnr(current);
 }
 
-#if defined(CONFIG_SLOB)
-
-/**
- * cs_round2 - Round up to power of 2 for calculating memory usage.
- *
- * @size: Size to be rounded up.
- *
- * Returns @size.
- *
- * Since SLOB does not round up, this function simply returns @size.
- */
-static inline int cs_round2(size_t size)
-{
-	return size;
-}
-
-#else
-
-/**
- * cs_round2 - Round up to power of 2 for calculating memory usage.
- *
- * @size: Size to be rounded up.
- *
- * Returns rounded size.
- *
- * Strictly speaking, SLAB may be able to allocate (e.g.) 96 bytes instead of
- * (e.g.) 128 bytes.
- */
-static inline int cs_round2(size_t size)
-{
-#if PAGE_SIZE == 4096
-	size_t bsize = 32;
-#else
-	size_t bsize = 64;
-#endif
-	if (!size)
-		return 0;
-	while (size > bsize)
-		bsize <<= 1;
-	return bsize;
-}
-
-#endif
-
 /**
  * cs_put_condition - Drop reference on "struct cs_condition".
  *
@@ -1119,6 +1079,22 @@ static inline void cs_put_name(const struct cs_path_info *name)
 /* For importing variables and functions. */
 extern struct caitsith_exports caitsith_exports;
 
+/**
+ * cs_ksize - Wrapper for ksize().
+ *
+ * @obj: Pointer to object.
+ *
+ * Returns ksize(@obj).
+ */
+static inline size_t cs_ksize(const void *obj)
+{
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+	return caitsith_exports.ksize(obj);
+#else
+	return ksize(obj);
+#endif
+}
+
 /*
  * Structure for holding "struct cs_domain_info *" and "u32 cs_flags" for
  * each "struct task_struct".
