@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.16   2016/06/07
+ * Version: 0.1.17   2016/09/28
  */
 
 #include <linux/version.h>
@@ -13,9 +13,6 @@
 #include <linux/sched.h>
 #include <linux/fs.h>
 #include <linux/namei.h>
-#ifndef LOOKUP_POSITIVE
-#define LOOKUP_POSITIVE 0
-#endif
 
 /*
  * TOMOYO specific part start.
@@ -76,8 +73,7 @@ static _Bool cs_policy_loader_exists(void)
 	struct path path;
 	if (!cs_loader)
 		cs_loader = CONFIG_CAITSITH_POLICY_LOADER;
-	if (kern_path(cs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE,
-		      &path) == 0) {
+	if (kern_path(cs_loader, LOOKUP_FOLLOW, &path) == 0) {
 		path_put(&path);
 		return 1;
 	}
@@ -85,8 +81,7 @@ static _Bool cs_policy_loader_exists(void)
 	struct nameidata nd;
 	if (!cs_loader)
 		cs_loader = CONFIG_CAITSITH_POLICY_LOADER;
-	if (path_lookup(cs_loader, LOOKUP_FOLLOW | LOOKUP_POSITIVE,
-			&nd) == 0) {
+	if (path_lookup(cs_loader, LOOKUP_FOLLOW, &nd) == 0) {
 		path_put(&nd.path);
 		return 1;
 	}
@@ -247,6 +242,9 @@ const struct caitsith_exports caitsith_exports = {
 #endif
 	.find_task_by_vpid = find_task_by_vpid,
 	.find_task_by_pid_ns = find_task_by_pid_ns,
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+	.ksize = ksize,
+#endif
 };
 #ifdef CONFIG_CAITSITH_LKM
 /* Only caitsith module need to access this struct. */
