@@ -3,18 +3,13 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.16   2016/06/07
+ * Version: 0.1.17   2016/09/28
  */
 
 #include "caitsith.h"
 
 /***** SECTION1: Constants definition *****/
 
-/* For compatibility with older kernels. */
-#ifndef for_each_process
-#define for_each_process for_each_task
-#endif
-
 /* The list for "struct cs_io_buffer". */
 static LIST_HEAD(cs_io_buffer_list);
 /* Lock for protecting cs_io_buffer_list. */
@@ -32,7 +27,6 @@ static void cs_collect_acl(struct list_head *list);
 static void cs_collect_entry(void);
 static void cs_collect_member(const enum cs_policy_id id,
 			      struct list_head *member_list);
-static void cs_memory_free(const void *ptr, const enum cs_policy_id type);
 static void cs_try_to_gc(const enum cs_policy_id type,
 			 struct list_head *element);
 
@@ -49,46 +43,6 @@ struct srcu_struct cs_ss;
 
 /***** SECTION6: Dependent functions section *****/
 
-/**
- * cs_memory_free - Free memory for elements.
- *
- * @ptr:  Pointer to allocated memory.
- * @type: One of values in "enum cs_policy_id".
- *
- * Returns nothing.
- *
- * Caller holds cs_policy_lock mutex.
- */
-static void cs_memory_free(const void *ptr, const enum cs_policy_id type)
-{
-	/* Size of an element. */
-	static const u8 e[CS_MAX_POLICY] = {
-		[CS_ID_GROUP] = sizeof(struct cs_group),
-#ifdef CONFIG_CAITSITH_NETWORK
-		[CS_ID_IP_GROUP] = sizeof(struct cs_ip_group),
-#endif
-		[CS_ID_STRING_GROUP] = sizeof(struct cs_string_group),
-		[CS_ID_NUMBER_GROUP] = sizeof(struct cs_number_group),
-		/* [CS_ID_CONDITION] = "struct cs_condition"->size, */
-		/* [CS_ID_NAME] = "struct cs_name"->size, */
-		/* [CS_ID_ACL] = sizeof(struct cs_acl_info), */
-		[CS_ID_DOMAIN] = sizeof(struct cs_domain_info),
-	};
-	size_t size;
-	if (type == CS_ID_ACL)
-		size = sizeof(struct cs_acl_info);
-	else if (type == CS_ID_NAME)
-		size = container_of(ptr, typeof(struct cs_name),
-				    head.list)->size;
-	else if (type == CS_ID_CONDITION)
-		size = container_of(ptr, typeof(struct cs_condition),
-				    head.list)->size;
-	else
-		size = e[type];
-	cs_memory_used[CS_MEMORY_POLICY] -= cs_round2(size);
-	kfree(ptr);
-}
-
 /**
  * cs_struct_used_by_io_buffer - Check whether the list element is used by /proc/caitsith/ users or not.
  *
@@ -392,7 +346,8 @@ static void cs_try_to_gc(const enum cs_policy_id type,
 		break;
 	}
 	mutex_lock(&cs_policy_lock);
-	cs_memory_free(element, type);
+	cs_memory_used[CS_MEMORY_POLICY] -= cs_ksize(element);
+	kfree(element);
 	return;
 reinject:
 	/*
