@@ -67,6 +67,9 @@ struct caitsith_exports {
 	struct task_struct * (*find_task_by_vpid) (pid_t nr);
 	struct task_struct * (*find_task_by_pid_ns) (pid_t nr,
 						     struct pid_namespace *ns);
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+	size_t (*ksize) (const void *objp);
+#endif
 };
 
 /* For doing access control. */
