@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2010-2013  Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
  *
- * Version: 0.1.16   2016/06/07
+ * Version: 0.1.17   2016/09/28
  */
 
 #include "caitsith.h"
@@ -1293,6 +1293,9 @@ static int __init cs_init(void)
 	caitsith_exports.vfsmount_lock = probe_vfsmount_lock();
 	if (!caitsith_exports.vfsmount_lock)
 		goto out;
+	caitsith_exports.ksize = probe_ksize();
+	if (!caitsith_exports.ksize)
+		goto out;
 	{
 		int idx;
 		for (idx = 0; idx < CS_MAX_TASK_SECURITY_HASH; idx++)
