@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.16   2016/06/07
+ * Version: 0.1.17   2016/09/28
  */
 
 #include "caitsith.h"
@@ -106,7 +106,6 @@ static bool cs_check_entry(struct cs_request_info *r,
 			   const struct cs_acl_info *ptr);
 static bool cs_condition(struct cs_request_info *r,
 			 const struct cs_condition *cond);
-static bool cs_decimal(const char c);
 static bool cs_file_matches_pattern(const char *filename,
 				    const char *filename_end,
 				    const char *pattern,
@@ -115,7 +114,6 @@ static bool cs_file_matches_pattern2(const char *filename,
 				     const char *filename_end,
 				     const char *pattern,
 				     const char *pattern_end);
-static bool cs_hexadecimal(const char c);
 static bool cs_number_matches_group(const unsigned long min,
 				    const unsigned long max,
 				    const struct cs_group *group);
@@ -399,11 +397,11 @@ oom:
 	 * there was a possibility of matching "deny" lines or not.
 	 */
 	{
-		static struct timeval cs_last_tv;
-		struct timeval tv;
-		do_gettimeofday(&tv);
-		if (tv.tv_sec != cs_last_tv.tv_sec) {
-			cs_last_tv = tv;
+		static unsigned long cs_last_oom;
+		unsigned long oom = get_seconds();
+
+		if (oom != cs_last_oom) {
+			cs_last_oom = oom;
 			printk(KERN_INFO "CaitSith: Rejecting access "
 			       "request due to out of memory.\n");
 		}
@@ -2401,7 +2399,7 @@ void cs_populate_patharg(struct cs_request_info *r, const bool first)
  * Returns true on success, false othwerwise.
  *
  * This function should not fail. But it can fail if (for example) out of
- * memory has occured while calculating cs_populate_patharg() or
+ * memory has occurred while calculating cs_populate_patharg() or
  * cs_get_exename().
  */
 static bool cs_cond2arg(struct cs_cond_arg *arg,
@@ -2722,13 +2720,12 @@ static bool cs_condition(struct cs_request_info *r,
 		const bool match = !condp->is_not;
 		condp++;
 		if (!cs_cond2arg(&left, left_op, &condp, r) ||
-		    !cs_cond2arg(&right, right_op, &condp, r)) {
+		    !cs_cond2arg(&right, right_op, &condp, r))
 			/*
 			 * Something wrong (e.g. out of memory or invalid
-			 * argument) occured. We can't check permission.
+			 * argument) occurred. We can't check permission.
 			 */
 			return false;
-		}
 		if (left.type == CS_ARG_TYPE_NUMBER) {
 			if (left_op == CS_ARGV_ENTRY) {
 				if (!r->bprm)
@@ -2864,32 +2861,6 @@ static bool cs_byte_range(const char *str)
 		*str >= '0' && *str <= '7';
 }
 
-/**
- * cs_decimal - Check whether the character is a decimal character.
- *
- * @c: The character to check.
- *
- * Returns true if @c is a decimal character, false otherwise.
- */
-static bool cs_decimal(const char c)
-{
-	return c >= '0' && c <= '9';
-}
-
-/**
- * cs_hexadecimal - Check whether the character is a hexadecimal character.
- *
- * @c: The character to check.
- *
- * Returns true if @c is a hexadecimal character, false otherwise.
- */
-static bool cs_hexadecimal(const char c)
-{
-	return (c >= '0' && c <= '9') ||
-		(c >= 'A' && c <= 'F') ||
-		(c >= 'a' && c <= 'f');
-}
-
 /**
  * cs_alphabet_char - Check whether the character is an alphabet.
  *
@@ -2940,11 +2911,11 @@ static bool cs_file_matches_pattern2(const char *filename,
 			}
 			break;
 		case '+':
-			if (!cs_decimal(c))
+			if (!isdigit(c))
 				return false;
 			break;
 		case 'x':
-			if (!cs_hexadecimal(c))
+			if (!isxdigit(c))
 				return false;
 			break;
 		case 'a':
@@ -2985,10 +2956,10 @@ static bool cs_file_matches_pattern2(const char *filename,
 			j = 0;
 			c = *pattern;
 			if (c == '$') {
-				while (cs_decimal(filename[j]))
+				while (isdigit(filename[j]))
 					j++;
 			} else if (c == 'X') {
-				while (cs_hexadecimal(filename[j]))
+				while (isxdigit(filename[j]))
 					j++;
 			} else if (c == 'A') {
 				while (cs_alphabet_char(filename[j]))
