@@ -719,3 +719,23 @@ void * __init probe_d_absolute_path(void)
 }
 
 #endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+
+/**
+ * probe_ksize - Find address of ksize().
+ *
+ * Returns address of ksize() on success, NULL otherwise.
+ */
+void * __init probe_ksize(void)
+{
+	void *ptr = probe_find_symbol(" ksize\n");
+	if (!ptr) {
+		printk(KERN_ERR "Can't resolve ksize().\n");
+		return NULL;
+	}
+	printk(KERN_INFO "ksize=%p\n", ptr);
+	return ptr;
+}
+
+#endif
