@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.16   2016/06/07
+ * Version: 0.1.17   2016/09/28
  */
 
 #include "caitsith.h"
@@ -342,9 +342,12 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 #if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
 		if (inode->i_op && !inode->i_op->rename)
 			goto prepend_filesystem_name;
-#else
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 9, 0)
 		if (!inode->i_op->rename && !inode->i_op->rename2)
 			goto prepend_filesystem_name;
+#else
+		if (!inode->i_op->rename)
+			goto prepend_filesystem_name;
 #endif
 	}
 	/* Prepend device name. */
@@ -458,12 +461,17 @@ char *cs_realpath(const struct path *path)
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
 			cs_realpath_unlock();
 		}
-#else
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(4, 9, 0)
 		if (!path->mnt ||
 		    (!inode->i_op->rename && !inode->i_op->rename2))
 			pos = ERR_PTR(-EINVAL);
 		else
 			pos = cs_get_absolute_path(path, buf, buf_len - 1);
+#else
+		if (!path->mnt || !inode->i_op->rename)
+			pos = ERR_PTR(-EINVAL);
+		else
+			pos = cs_get_absolute_path(path, buf, buf_len - 1);
 #endif
 		if (pos == ERR_PTR(-EINVAL))
 			pos = cs_get_local_path(path->dentry, buf,
