@@ -34,6 +34,10 @@ static int __init cs_init(void)
 #else
 	if (!probe_d_absolute_path())
 		goto out;
+#endif
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+	if (!probe_ksize())
+		goto out;
 #endif
 	printk(KERN_INFO "All dependent symbols have been guessed.\n");
 	printk(KERN_INFO "Please verify these addresses using System.map for "
